@@ -27,7 +27,7 @@ def main():
       pygame.K_d: 'right',
       pygame.K_w: 'up',
       pygame.K_s: 'down',
-      pygame.K_SPACE: 'grab_or_attack',
+      pygame.K_SPACE: 'interact',
       pygame.K_1: 'place_stone',
       pygame.K_2: 'place_table',
       pygame.K_3: 'place_furnace',
@@ -35,7 +35,7 @@ def main():
       pygame.K_5: 'make_stone_pickaxe',
       pygame.K_6: 'make_iron_pickaxe',
   }
-  print('\nActions:')
+  print('Actions:')
   for key, action in keymap.items():
     print(f'  {pygame.key.name(key)}: {action}')
 
@@ -45,11 +45,12 @@ def main():
   inventory = None
   health = None
   achievements = set()
+  return_ = 0
   if args.record:
     frames = []
 
   diamond = crafter.crafter.MATERIAL_IDS['diamond']
-  print('\nDiamonds:', (env._terrain == diamond).sum())
+  print('Diamonds exist:', (env._terrain == diamond).sum())
 
   pygame.init()
   screen = pygame.display.set_mode([args.window, args.window])
@@ -74,26 +75,30 @@ def main():
       else:
         action = 'noop'
 
+    messages = []
     obs, reward, done, _ = env.step(env.action_names.index(action))
     if len(env._player.achievements) > len(achievements):
       for name in env._player.achievements:
         if name not in achievements:
-          print(f'\nAchievement ({len(env._player.achievements)}/13): {name}')
+          count = len(env._player.achievements)
+          messages.append(f'Achievement ({count}/13): {name}')
       achievements = env._player.achievements.copy()
+    if env._step > 0 and env._step % 100 == 0:
+      messages.append(f'Time step: {env._step}')
     if not health or health != env._player.health:
       health = env._player.health
-      print(f'\nHealth: {health}/{args.health}')
+      messages.append(f'Health: {health}/{args.health}')
+    if reward:
+      messages.append(f'Reward: {reward}')
+      return_ += reward
+    if done:
+      messages.append(f'Episode end: {done}')
     if not inventory or inventory != env._player.inventory:
       inventory = env._player.inventory.copy()
-      print('\nInventory:')
-      for key, value in inventory.items():
-        print(f'  {key}: {value}')
-    if env._step > 0 and env._step % 100 == 0:
-      print(f'\nTime step: {env._step}')
-    if reward:
-      print('\nReward:', reward)
-    if done:
-      print('\nDone:', done)
+      content = ', '.join(f'{v} {k}' for k, v in inventory.items())
+      messages.append(f'Inventory: {content}')
+    if messages:
+      print('\n', '\n'.join(messages), sep='')
 
     if args.record:
       frames.append(obs['image'])
@@ -104,6 +109,7 @@ def main():
     clock.tick(args.fps)
 
   pygame.quit()
+  print('Return:', return_)
   if args.record:
     imageio.mimsave(args.record, frames)
     print('Saved', args.record)
